@@ -1,6 +1,7 @@
 # ABAT test for panicsel component utilities
 # tag: rh71__build
-util=/usr/share/panicsel/showsel
+# util=/usr/share/panicsel/showsel
+util=/usr/sbin/isel
 echo "panicsel component, basic acceptance test"
 if [ ! -f $util ]
 then
