@@ -441,7 +441,7 @@ SendTimedIpmbpRequest (
 					sizeof( responseData ),
 					& respLength,
 					NULL);
-	if (fdebug) printf("sendIpmb: send_message status=%d rlen=%d cc=%x\n",
+	if (fdebug) printf("sendIpmb: send_message status=%d rlen=%lu cc=%x\n",
 				status,respLength,resp->cCode);
 	if ( status != TRUE ) {
 		DWORD error;
@@ -478,7 +478,7 @@ SendTimedIpmbpRequest (
 					sizeof( responseData ),
 					& respLength,
 					NULL);
-	if (fdebug) printf("sendIpmb: get_message status=%d rlen=%d cc=%x\n",
+	if (fdebug) printf("sendIpmb: get_message status=%d rlen=%lu cc=%x\n",
 				status,respLength,resp->cCode);
 	if ( status != TRUE ) {
 		DWORD error;
@@ -1322,7 +1322,7 @@ SendTimedEmpMessageResponse_Ex (
 #endif
 
 	if (fdebug) {
-		   printf("SendTimedEmp(%x,%x): status=%d cc=%x rlen=%d i=%d\n",
+		   printf("SendTimedEmp(%x,%x): status=%d cc=%x rlen=%lu i=%d\n",
 				sessionHandle, channelNumber,
 				status,responseData[0],respLength,i);
 		   _dump_buf("requestData",requestData,sizeof(requestData),0);
@@ -1428,7 +1428,7 @@ SendTimedLanMessageResponse(
 				  );
 
 	if (fdebug) {
-		   printf("SendTimedLan(): status=%d cc=%x rlen=%d i=%d\n",
+		   printf("SendTimedLan(): status=%d cc=%x rlen=%lu i=%d\n",
 				status, responseData[0],respLength,i);
 		   _dump_buf("requestData",requestData,sizeof(requestData),0);
 	}
@@ -1579,7 +1579,7 @@ SendTimedLanMessageResponse_Ex(
 	DEBUG("%s: DeviceIoControl status = %d\n",__FUNCTION__, status);
 #endif
 	if (fdebug) {
-	   printf("SendTimedLan(%x,%x): status=%d cc=%x rlen=%d i=%d\n",
+	   printf("SendTimedLan(%x,%x): status=%d cc=%x rlen=%lu i=%d\n",
 				sessionHandle, channelNumber,
 				status,responseData[0],respLength,i);
 	   if (responseData[0] != 0)  /*0xcc == invalid request data*/
@@ -2020,7 +2020,7 @@ IsAsyncMessageAvailable (HandleType   eventId )
 
 	if ( AsyncEventHandle  != eventId) {
 #ifdef LINUX
-		printf("Invalid AsyncHandle %x!=%x\n",AsyncEventHandle,eventId);
+		printf("Invalid AsyncHandle %lx!=%lx\n",AsyncEventHandle,eventId);
 #endif
 	  	return ACCESN_ERROR;
 	}
@@ -2239,7 +2239,7 @@ RegisterForImbAsyncMessageNotification (HandleType *handleId)
 	
 	if( (respLength != sizeof(int))  || (status != TRUE )) {
 		if (fdebug) {
-		   printf("RegisterForImbAsync error status=%d, len=%d sizeint=%d\n", status, respLength, sizeof(int));
+		   printf("RegisterForImbAsync error status=%d, len=%lu sizeint=%lu\n", status, respLength, sizeof(int));
 		  if( respLength != sizeof(int)) printf("Async len err\n");
 	 	  if( status != TRUE) printf("Async status err\n");
 		}
