@@ -165,8 +165,13 @@ void dbglog( char *pattn, ... ); /*local prototype*/
 /*
  * Global variables 
  */
-static char * progver   = "3.07";
+#ifdef METACOMMAND
+extern char * progver;  /*from ipmiutil.c*/
+static char * progname  = "ipmiutil sol";
+#else
+static char * progver   = "3.08";
 static char * progname  = "isol";
+#endif
 static char  fdebug        = 0;
 static char  fpicmg        = 0;
 static char  factivate     = 0;
